

Glossary
========

.. glossary::
   :sorted:

   SKOS
    `Simple Knowledge Organization System <http://www.w3.org/2004/02/skos>`__. An
    general specification for Knowledge Organisation Systems (thesauri, word 
    lists, authority files, ...) that is commonly serialised as :term:`RDF`.

   SKOS-THES
    The `ISO 25964 SKOS extension <http://pub.tenforce.com/schemas/iso25964/skos-thes/>`_
    defines mappings between the ISO 25964 standard and the :term:`SKOS` 
    specification.

   RDF
    `Resource Description Framework <http://www.w3.org/RDF/>`__. A very flexible 
    model for data definition organised around `triples`. These triples forms a 
    directed, labeled graph, where the edges represent the named link between 
    two resources, represented by the graph nodes.

   URI
    A `Uniform Resource Identifier`.

   URN
    A URN is a specific form of a :term:`URI`.

   Pyramid
    This webframework was used to implement the server side components of
    Atramhasis.

   HTML
    HyperText Markup Language is the markup language used to create webpage.

   CSS
    Cascading Style Sheet is a style specification used to add style and 
    presentation to webpages.

   SOA
    `Service Oriented Architecture <http://en.wikipedia.org/wiki/Service-oriented_architecture>`__.

   REST
    REST or `REpresentational State Transfer` is a way of data exchange that
    is very complimentary to the operations of the HTTP protcol.

   Jinja2
    `Jinja2 <http://jinja.pocoo.org>`__ is a python templating engine. It's
    used by Atramhasis for rendering :term:`HTML` templates.

   HDT
    `HDT <http://www.rdfhdt.org>`__ (Header, Dictionary, Triples) is a 
    compact data structure and binary serialization format for RDF that keeps
    big datasets compressed to save space while maintaining search and browse
    operations without prior decompression. This makes it an ideal format for 
    storing and sharing RDF datasets on the Web.
